@@ -11,7 +11,7 @@ use Raisin::Response;
 use Raisin::Routes;
 use Raisin::Util;
 
-our $VERSION = '0.61';
+our $VERSION = '0.62';
 
 sub new {
     my ($class, %args) = @_;
@@ -149,7 +149,8 @@ sub psgi {
         }
 
         my $type = $req->accept_format;
-        if (   ($req->header('Accept') && !$type)
+        my $accept = $req->header('Accept');
+        if (   ($accept && $accept ne '*/*' && !$type)
             || (($self->api_format && $type) && ($self->api_format ne $type)))
         {
             $self->log(error => 'Content-type provided not acceptable');
@@ -1067,7 +1068,7 @@ which was inspired by L<Dancer>, which in its turn was inspired by Sinatra.
 
 =head1 AUTHOR
 
-Artur Khabibullin - rtkh E<lt>atE<gt> cpan.org
+Artur Khabibullin - rtkh@cpan.org
 
 =head1 LICENSE
 
