@@ -21,8 +21,23 @@ sub accept_format {
 
     my $accept = $self->header('Accept');
     return unless $accept;
-    return if $accept eq '*/*';
-    Raisin::Util::detect_serializer($accept) || $accept;
+
+    my %media_types;
+    for my $type (split /\s*,\s*/, $accept) {
+        my ($media, $params) = split /;/, $type, 2;
+
+        next
+            if $media eq '*/*'
+            || !($media = Raisin::Util::detect_serializer($media));
+
+        my $q = defined $params && $params =~ /q=([\d\.]+)/ ? $1 : 1;
+
+        $media_types{$media} = $q;
+        last if $q == 1;
+    }
+
+    my ($media) = sort { $media_types{$b} <=> $media_types{$a} } keys %media_types;
+    $media;
 }
 
 sub deserialize {
@@ -50,10 +65,10 @@ sub prepare_params {
     $self->{'raisin.declared'} = $declared;
 
     # Serialization / Deserialization
-    my $content_params = do {
+    my $body_params = do {
         if ($self->method =~ /POST|PUT/ && (my $content = $self->content)) {
             if ($self->content_type =~ m{application/x-www-form-urlencoded}imsx) {
-                $self->body_parameters->mixed;
+                $self->body_parameters->as_hashref_mixed;
             }
             else {
                 $self->deserialize($content);
@@ -61,14 +76,14 @@ sub prepare_params {
         }
     };
 
-    my $query_params = $self->query_parameters->mixed;
-    my $params = { %{ $content_params || {} }, %{ $query_params || {} } };
+    my $query_params = $self->query_parameters->as_hashref_mixed;
+    my $params = { %{ $body_params || {} }, %{ $query_params || {} } };
+
+    $self->{'raisin.parameters'} = { %$params, %{ $named || {} } };
 
     foreach my $p (@$declared) {
         my $name = $p->name;
 
-        #$self->{'raisin.params'}{$name} = undef;
-
         # a route params have a precedence over query params
         my $value = $named->{$name} // $params->{$name};
 
@@ -79,13 +94,18 @@ sub prepare_params {
         $value //= $p->default if defined $p->default;
         next if not defined($value);
 
-        $self->{'raisin.params'}{$name} = $value;
+        $self->{'raisin.declared_params'}{$name} = $value;
     }
 
     1;
 }
 
-sub declared_params { shift->{'raisin.params'} }
+sub declared_params { shift->{'raisin.declared_params'} }
+
+sub raisin_parameters {
+    my $self = shift;
+    $self->{'raisin.parameters'};
+}
 
 1;
 
@@ -113,6 +133,8 @@ Extends L<Plack::Request>.
 
 =head3 prepare_params
 
+=head3 raisin_parameters
+
 =head1 AUTHOR
 
 Artur Khabibullin - rtkh E<lt>atE<gt> cpan.org
