@@ -3,6 +3,7 @@ package Raisin::Routes::Endpoint;
 use strict;
 use warnings;
 
+use Raisin::Util;
 use Raisin::Attributes;
 
 has 'api_format';
@@ -51,7 +52,8 @@ sub _build_regex {
             "(?<format>\.${ \$self->api_format })?";
         }
         else {
-            '(?<format>\.\w+)?';
+            my $se = join '|', Raisin::Util::valid_extensions();
+            "(?<format>(?:\.(?:$se))?)?";
         }
     };
 
@@ -65,7 +67,7 @@ sub _rep_regex {
 
     for ($switch) {
         if ($_ eq ':' || $_ eq '?') {
-            $r = $a . ($self->check->{$token} // '[^/.]+') . $b;
+            $r = $a . ($self->check->{$token} // '[^/]+?') . $b;
         }
         if ($_ eq '*') {
             $r = $a . '.+' . $b;
@@ -99,8 +101,7 @@ sub match {
 
     my %captured = %+;
 
-    if ($captured{format}) {
-        my $format = delete $captured{format};
+    if (my $format = delete $captured{format}) {
         # delete prepending full stop
         $self->format(substr($format, 1));
     }
